powered by
Compare a patient's score to a control group.
assess( patient, mean = 0, sd = 1, n = NULL, controls = NULL, CI = 95, treshold = 0.05, iter = 10000, color_controls = "#2196F3", color_CI = "#E91E63", color_score = "black", color_size = 2, alpha_controls = 1, alpha_CI = 0.8, verbose = TRUE )
output
Single value (patient's score).
Mean of the control sample.
SD of the control sample.
Size of the control sample.
Vector of values (control's scores).
Credible interval bounds.
Significance treshold.
Number of iterations.
Color of the controls distribution.
Color of CI distribution.
Color of the line representing the patient's score.
Size of the line representing the patient's score.
Alpha of the CI distribution.
lpha of the controls distribution.
Print possible warnings.
Dominique Makowski
Until relatively recently the standard way of testing for a difference between a case and controls was to convert the case’s score to a z score using the control sample mean and standard deviation (SD). If z was less than -1.645 (i.e., below 95
result <- assess(patient = 124, mean = 100, sd = 15, n = 100) print(result) plot(result)
Run the code above in your browser using DataLab