Learn R Programming

psycho (version 0.6.2)

crawford.test.freq: Crawford-Howell (1998) frequentist t-test for single-case analysis.

Description

Neuropsychologists often need to compare a single case to a small control group. However, the standard two-sample t-test does not work because the case is only one observation. Crawford and Garthwaite (2012) demonstrate that the Crawford-Howell (1998) t-test is a better approach (in terms of controlling Type I error rate) than other commonly-used alternatives. .

Usage

crawford.test.freq(patient, controls)

Value

Returns a data frame containing the t-value, degrees of freedom, and p-value. If significant, the patient is different from the control group.

Arguments

patient

Single value (patient's score).

controls

Vector of values (control's scores).

Author

Dan Mirman, Dominique Makowski

Examples

Run this code
library(psycho)

crawford.test.freq(patient = 10, controls = c(0, -2, 5, 2, 1, 3, -4, -2))
crawford.test.freq(patient = 7, controls = c(0, -2, 5, 2, 1, 3, -4, -2))

Run the code above in your browser using DataLab